@@ -57,6 +57,10 @@ func TestDefaultWindowsShell(t *testing.T) {
 			shell:         "powershell",
 			expectedShell: "powershell",
 		},
+		{
+			shell:         "pwsh",
+			expectedShell: "pwsh",
+		},
 		{
 			shell:         "",
 			expectedShell: "powershell",
