@@ -36,12 +36,12 @@ type requestCredentials interface {
 	GetTLSKeyFile() string
 }
 
-var (
-	dialer = net.Dialer{
-		Timeout:   30 * time.Second,
-		KeepAlive: 30 * time.Second,
-	}
+var dialer = net.Dialer{
+	Timeout:   30 * time.Second,
+	KeepAlive: 30 * time.Second,
+}
 
+const (
 	backOffDelayMin    = 100 * time.Millisecond
 	backOffDelayMax    = 60 * time.Second
 	backOffDelayFactor = 2.0
@@ -105,43 +105,55 @@ func (n *client) ensureTLSConfig() {
 
 func (n *client) addTLSCA(tlsConfig *tls.Config) {
 	// load TLS CA certificate
-	if file := n.caFile; file != "" && !n.skipVerify {
-		logrus.Debugln("Trying to load", file, "...")
+	file := n.caFile
+	if file == "" || n.skipVerify {
+		return
+	}
 
-		data, err := ioutil.ReadFile(file)
-		if err == nil {
-			pool, err := x509.SystemCertPool()
-			if err != nil {
-				logrus.Warningln("Failed to load system CertPool:", err)
-			}
-			if pool == nil {
-				pool = x509.NewCertPool()
-			}
-			if pool.AppendCertsFromPEM(data) {
-				tlsConfig.RootCAs = pool
-				n.caData = data
-			} else {
-				logrus.Errorln("Failed to parse PEM in", n.caFile)
-			}
-		} else if !os.IsNotExist(err) {
+	logrus.Debugln("Trying to load", file, "...")
+
+	data, err := ioutil.ReadFile(file)
+	if err != nil {
+		if !os.IsNotExist(err) {
 			logrus.Errorln("Failed to load", n.caFile, err)
 		}
+		return
 	}
+
+	pool, err := x509.SystemCertPool()
+	if err != nil {
+		logrus.Warningln("Failed to load system CertPool:", err)
+	}
+	if pool == nil {
+		pool = x509.NewCertPool()
+	}
+	if !pool.AppendCertsFromPEM(data) {
+		logrus.Errorln("Failed to parse PEM in", n.caFile)
+		return
+	}
+
+	tlsConfig.RootCAs = pool
+	n.caData = data
 }
 
 func (n *client) addTLSAuth(tlsConfig *tls.Config) {
-	// load TLS client keypair
-	if cert, key := n.certFile, n.keyFile; cert != "" && key != "" {
-		logrus.Debugln("Trying to load", cert, "and", key, "pair...")
-
-		certificate, err := tls.LoadX509KeyPair(cert, key)
-		if err == nil {
-			tlsConfig.Certificates = []tls.Certificate{certificate}
-			tlsConfig.BuildNameToCertificate()
-		} else if !os.IsNotExist(err) {
-			logrus.Errorln("Failed to load", cert, key, err)
-		}
+	if n.certFile == "" || n.keyFile == "" {
+		return
 	}
+
+	logrus.Debugln("Trying to load", n.certFile, "and", n.keyFile, "pair...")
+
+	// load TLS client keypair
+	certificate, err := tls.LoadX509KeyPair(n.certFile, n.keyFile)
+	if err != nil {
+		if !os.IsNotExist(err) {
+			logrus.Errorln("Failed to load", n.certFile, n.keyFile, err)
+		}
+		return
+	}
+
+	tlsConfig.Certificates = []tls.Certificate{certificate}
+	tlsConfig.BuildNameToCertificate()
 }
 
 func (n *client) createTransport() {
@@ -201,16 +213,21 @@ func (n *client) checkBackoffRequest(req *http.Request, res *http.Response) {
 	}
 }
 
-func (n *client) do(uri, method string, request io.Reader, requestType string, headers http.Header) (res *http.Response, err error) {
+func (n *client) do(
+	uri, method string,
+	request io.Reader,
+	requestType string,
+	headers http.Header,
+) (*http.Response, error) {
 	url, err := n.url.Parse(uri)
 	if err != nil {
-		return
+		return nil, err
 	}
 
 	req, err := http.NewRequest(method, url.String(), request)
 	if err != nil {
 		err = fmt.Errorf("failed to create NewRequest: %w", err)
-		return
+		return nil, err
 	}
 
 	if headers != nil {
@@ -224,16 +241,21 @@ func (n *client) do(uri, method string, request io.Reader, requestType string, h
 
 	n.ensureTLSConfig()
 
-	res, err = n.requester.Do(req)
+	res, err := n.requester.Do(req)
 	if err != nil {
-		return
+		return nil, err
 	}
 
 	n.checkBackoffRequest(req, res)
-	return
+	return res, nil
 }
 
-func (n *client) doJSON(uri, method string, statusCode int, request interface{}, response interface{}) (int, string, *http.Response) {
+func (n *client) doJSON(
+	uri, method string,
+	statusCode int,
+	request interface{},
+	response interface{},
+) (int, string, *http.Response) {
 	var body io.Reader
 
 	if request != nil {
@@ -253,21 +275,21 @@ func (n *client) doJSON(uri, method string, statusCode int, request interface{},
 	if err != nil {
 		return -1, err.Error(), nil
 	}
-	defer res.Body.Close()
-	defer io.Copy(ioutil.Discard, res.Body)
+	defer func() {
+		_, _ = io.Copy(ioutil.Discard, res.Body)
+		_ = res.Body.Close()
+	}()
 
-	if res.StatusCode == statusCode {
-		if response != nil {
-			isApplicationJSON, err := isResponseApplicationJSON(res)
-			if !isApplicationJSON {
-				return -1, err.Error(), nil
-			}
+	if res.StatusCode == statusCode && response != nil {
+		isApplicationJSON, err := isResponseApplicationJSON(res)
+		if !isApplicationJSON {
+			return -1, err.Error(), nil
+		}
 
-			d := json.NewDecoder(res.Body)
-			err = d.Decode(response)
-			if err != nil {
-				return -1, fmt.Sprintf("Error decoding json payload %v", err), nil
-			}
+		d := json.NewDecoder(res.Body)
+		err = d.Decode(response)
+		if err != nil {
+			return -1, fmt.Sprintf("Error decoding json payload %v", err), nil
 		}
 	}
 
@@ -343,18 +365,17 @@ func (n *client) findCertificate(certificate *string, base string, name string)
 	}
 }
 
-func newClient(requestCredentials requestCredentials) (c *client, err error) {
+func newClient(requestCredentials requestCredentials) (*client, error) {
 	url, err := url.Parse(fixCIURL(requestCredentials.GetURL()) + "/api/v4/")
 	if err != nil {
-		return
+		return nil, err
 	}
 
 	if url.Scheme != "http" && url.Scheme != "https" {
-		err = errors.New("only http or https scheme supported")
-		return
+		return nil, errors.New("only http or https scheme supported")
 	}
 
-	c = &client{
+	c := &client{
 		url:             url,
 		caFile:          requestCredentials.GetTLSCAFile(),
 		certFile:        requestCredentials.GetTLSCertFile(),
@@ -370,5 +391,5 @@ func newClient(requestCredentials requestCredentials) (c *client, err error) {
 		c.findCertificate(&c.keyFile, CertificateDirectory, host+".auth.key")
 	}
 
-	return
+	return c, nil
 }
